========
Examples
========

.. toctree::
  :maxdepth: 2


.. fancy_include:: simple_phase.py

.. fancy_include:: background_ramp.py

.. fancy_include:: background_offset.py

.. fancy_include:: hologram_cell.py
